@@ -33,9 +33,9 @@ created in their own module.  The module defining the Script subclass
 is also required to have a 'getScript(app)' method that returns an
 instance of the Script subclass.  See default.py for an example."""
 
-__id__        = "$Id: script.py 2514 2007-07-03 13:15:24Z shaeger $"
-__version__   = "$Revision: 2514 $"
-__date__      = "$Date: 2007-07-03 09:15:24 -0400 (Tue, 03 Jul 2007) $"
+__id__        = "$Id: script.py 2573 2007-07-31 16:11:39Z richb $"
+__version__   = "$Revision: 2573 $"
+__date__      = "$Date: 2007-07-31 12:11:39 -0400 (Tue, 31 Jul 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -80,6 +80,7 @@ class Script:
         self.setupInputEventHandlers()
         self.keyBindings = self.getKeyBindings()
         self.brailleBindings = self.getBrailleBindings()
+        self.app_pronunciation_dict = self.getPronunciations()
 
         self.brailleGenerator = self.getBrailleGenerator()
         self.speechGenerator = self.getSpeechGenerator()
@@ -149,6 +150,15 @@ class Script:
         """
         return {}
 
+    def getPronunciations(self):
+        """Defines the application specific pronunciations for this script.
+
+        Returns a dictionary where the keys are the actual text strings and
+        the values are the replacement strings that are spoken instead.
+        """
+
+        return {}
+
     def getBrailleCommandsForInputHandler(self, inputEventHandler):
         """Returns a list of BrlTTY commands (they're in braille.py) that
         match the given inputEventHandler passed as argument.
@@ -212,6 +222,16 @@ class Script:
 
         return keyBindings
 
+    def overridePronunciations(self, script, pronunciations):
+        """Allow for the customization of application specific pronunciations.
+
+        Arguments:
+        - script: the application script.
+        - pronunciations: the dictionary of pronunciations for this script.
+        """
+
+        return pronunciationDict
+
     def getAppState(self):
         """Returns an object that can be passed to setAppState.  This
         object will be used by setAppState to restore any state
