@@ -19,9 +19,9 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: Evolution.py 2520 2007-07-06 19:51:57Z joanied $"
-__version__   = "$Revision: 2520 $"
-__date__      = "$Date: 2007-07-06 15:51:57 -0400 (Fri, 06 Jul 2007) $"
+__id__        = "$Id: Evolution.py 2590 2007-08-03 20:47:00Z joanied $"
+__version__   = "$Revision: 2590 $"
+__date__      = "$Date: 2007-08-03 16:47:00 -0400 (Fri, 03 Aug 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -115,13 +115,14 @@ class WhereAmI(where_am_I.WhereAmI):
                     if (current-1) >= 0:
                         prevPanel = container.child(current-1)
                         prevObj = prevPanel.child(0)
-                        if prevObj.text.getNSelections() > 0:
-                            otherSelected = True
-                        else:
-                            displayedText = prevObj.text.getText(0, -1)
-                            if len(displayedText) == 0:
-                                current -= 1
-                                morePossibleSelections = True
+                        if prevObj and prevObj.text:
+                            if prevObj.text.getNSelections() > 0:
+                                otherSelected = True
+                            else:
+                                displayedText = prevObj.text.getText(0, -1)
+                                if len(displayedText) == 0:
+                                    current -= 1
+                                    morePossibleSelections = True
 
                 current = obj.parent.index
                 morePossibleSelections = True
@@ -130,13 +131,14 @@ class WhereAmI(where_am_I.WhereAmI):
                     if (current+1) < container.childCount:
                         nextPanel = container.child(current+1)
                         nextObj = nextPanel.child(0)
-                        if nextObj.text.getNSelections() > 0:
-                            otherSelected = True
-                        else:
-                            displayedText = nextObj.text.getText(0, -1)
-                            if len(displayedText) == 0:
-                                current += 1
-                                morePossibleSelections = True
+                        if nextObj and nextObj.text:
+                            if nextObj.text.getNSelections() > 0:
+                                otherSelected = True
+                            else:
+                                displayedText = nextObj.text.getText(0, -1)
+                                if len(displayedText) == 0:
+                                    current += 1
+                                    morePossibleSelections = True
 
         return [currentSelected, otherSelected]
 
